@@ -1,22 +1,21 @@
 import os
-import unittest
-import tempfile
 import shutil
+import tempfile
+import unittest
+
+from catkin_pkg.package import Dependency, Export, PACKAGE_MANIFEST_FILENAME, parse_package, Url
+from catkin_pkg.package_templates import _create_include_macro, _create_targetlib_args, _safe_write_files, \
+    create_cmakelists, create_package_files, create_package_xml, PackageTemplate
+from catkin_pkg.python_setup import generate_distutils_setup
 
 from mock import MagicMock, Mock
 
-from catkin_pkg.package_templates import _safe_write_files, create_package_files, \
-    create_cmakelists, create_package_xml, PackageTemplate, _create_include_macro, \
-    _create_targetlib_args
-from catkin_pkg.package import parse_package, Dependency, Export, Url, PACKAGE_MANIFEST_FILENAME
-from catkin_pkg.python_setup import generate_distutils_setup
 
-
-def u(str):
+def u(line):
     try:
-        return unicode(str)
+        return unicode(line)
     except NameError:
-        return str
+        return line
 
 
 class TemplateTest(unittest.TestCase):
@@ -120,20 +119,22 @@ class TemplateTest(unittest.TestCase):
         mock_pack.boost_comps = []
         mock_pack.system_deps = ['log4cxx', 'BZip2']
         statement = _create_include_macro(mock_pack)
-        self.assertEqual('# include\n  ${catkin_INCLUDE_DIRS}\n# TODO: Check names of system library include directories (log4cxx, BZip2)\n  ${log4cxx_INCLUDE_DIRS}\n  ${BZip2_INCLUDE_DIRS}', statement)
+        self.assertEqual('# include\n  ${catkin_INCLUDE_DIRS}\n# TODO: Check names of system library include directories (log4cxx, BZip2)\n'
+                         '  ${log4cxx_INCLUDE_DIRS}\n  ${BZip2_INCLUDE_DIRS}', statement)
         mock_pack.catkin_deps = ['roscpp']
         mock_pack.boost_comps = ['thread', 'filesystem']
         mock_pack.system_deps = ['log4cxx', 'BZip2']
         statement = _create_include_macro(mock_pack)
-        self.assertEqual('# include\n  ${catkin_INCLUDE_DIRS}\n  ${Boost_INCLUDE_DIRS}\n# TODO: Check names of system library include directories (log4cxx, BZip2)\n  ${log4cxx_INCLUDE_DIRS}\n  ${BZip2_INCLUDE_DIRS}', statement)
+        self.assertEqual('# include\n  ${catkin_INCLUDE_DIRS}\n  ${Boost_INCLUDE_DIRS}\n# TODO: Check names of system library include directories (log4cxx, BZip2)\n'
+                         '  ${log4cxx_INCLUDE_DIRS}\n  ${BZip2_INCLUDE_DIRS}', statement)
 
     def test_create_package(self):
         maint = self.get_maintainer()
         pack = PackageTemplate(name='bar',
                                description='bar',
                                package_format='1',
-                               version='0.0.0',
-                               version_abi='pabi',
+                               version='0.0.1',
+                               version_compatibility='0.0.0',
                                maintainers=[maint],
                                licenses=['BSD'])
         try:
@@ -157,8 +158,8 @@ class TemplateTest(unittest.TestCase):
         maint = self.get_maintainer()
         pack = PackageTemplate(name='bar',
                                package_format=2,
-                               version='0.0.0',
-                               version_abi='pabi',
+                               version='0.0.1',
+                               version_compatibility='0.0.0',
                                urls=[Url('foo')],
                                description='pdesc',
                                maintainers=[maint],
@@ -175,7 +176,7 @@ class TemplateTest(unittest.TestCase):
             self.assertEqual(pack.name, pack_result.name)
             self.assertEqual(pack.package_format, pack_result.package_format)
             self.assertEqual(pack.version, pack_result.version)
-            self.assertEqual(pack.version_abi, pack_result.version_abi)
+            self.assertEqual(pack.version_compatibility, pack_result.version_compatibility)
             self.assertEqual(pack.description, pack_result.description)
             self.assertEqual(pack.maintainers[0].name, pack_result.maintainers[0].name)
             self.assertEqual(pack.maintainers[0].email, pack_result.maintainers[0].email)
@@ -197,7 +198,7 @@ class TemplateTest(unittest.TestCase):
                               'maintainer_email': 'foo@bar.com',
                               'description': 'pdesc',
                               'license': 'BSD',
-                              'version': '0.0.0',
+                              'version': '0.0.1',
                               'author': '',
                               'url': 'foo'}, rdict)
         finally:
@@ -208,8 +209,8 @@ class TemplateTest(unittest.TestCase):
         maint = self.get_maintainer()
         pack = PackageTemplate(name='bar',
                                package_format=2,
-                               version='0.0.0',
-                               version_abi='pabi',
+                               version='0.0.1',
+                               version_compatibility='0.0.0',
                                description='pdesc',
                                maintainers=[maint, maint],
                                authors=[maint, maint],
@@ -250,7 +251,7 @@ class TemplateTest(unittest.TestCase):
             self.assertEqual(pack.name, pack_result.name)
             self.assertEqual(pack.package_format, pack_result.package_format)
             self.assertEqual(pack.version, pack_result.version)
-            self.assertEqual(pack.version_abi, pack_result.version_abi)
+            self.assertEqual(pack.version_compatibility, pack_result.version_compatibility)
             self.assertEqual(pack.description, pack_result.description)
             self.assertEqual(len(pack.maintainers), len(pack_result.maintainers))
             self.assertEqual(len(pack.authors), len(pack_result.authors))
@@ -280,7 +281,7 @@ class TemplateTest(unittest.TestCase):
                               'maintainer': u('John Foo <foo@bar.com>, John Foo <foo@bar.com>'),
                               'description': 'pdesc',
                               'license': 'BSD, MIT',
-                              'version': '0.0.0',
+                              'version': '0.0.1',
                               'author': u('John Foo <foo@bar.com>, John Foo <foo@bar.com>'),
                               'url': 'bar'}, rdict)
         finally:
